@@ -1,4 +1,4 @@
-{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE FlexibleContexts, FlexibleInstances, OverloadedStrings, ScopedTypeVariables, UndecidableInstances #-}
 module Debian.Control.Common
     ( -- * Types
       Control'(..)
@@ -15,16 +15,22 @@ module Debian.Control.Common
     , raiseFields
     , parseControlFromCmd
     , md5sumField
+    , protectFieldText'
     )
     where
 
-import Data.List (partition, intersperse)
+import Data.Char (isSpace)
+import Data.List as List (dropWhileEnd, partition, intersperse)
+import Data.ListLike as LL (ListLike, cons, dropWhileEnd, empty, find, null, singleton)
+import Data.ListLike.String as LL (StringLike, lines, unlines)
 import Data.Monoid ((<>))
-import Debian.Pretty (Doc, text, Pretty(pretty), cat, vcat)
+import Debian.Pretty (PP(..))
 import System.Exit (ExitCode(ExitSuccess, ExitFailure))
 import System.IO (Handle)
 import System.Process (runInteractiveCommand, waitForProcess)
 import Text.ParserCombinators.Parsec (ParseError)
+import Text.PrettyPrint (Doc, text, hcat)
+import Text.PrettyPrint.HughesPJClass (Pretty(pPrint))
 
 newtype Control' a
     = Control { unControl :: [Paragraph' a] } deriving (Eq, Ord, Read, Show)
@@ -55,32 +61,61 @@ class ControlFunctions a where
     -- string. Folded whitespace is /not/ unfolded. This should probably
     -- be moved to someplace more general purpose.
     stripWS :: a -> a
+    -- |Protect field value text so the parser doesn't split it into
+    -- multiple fields or paragraphs.  This must modify all field text
+    -- to enforce two conditions: (1) All lines other than the initial
+    -- one must begin with a space or a tab, and (2) the trailing
+    -- white space must not contain newlines.  This is called before
+    -- pretty printing to prevent the parser from misinterpreting
+    -- field text as multiple fields or paragraphs.
+    protectFieldText :: a -> a
     asString :: a -> String
 
--- |This may have bad performance issues (why?)
-instance Pretty a => Pretty (Control' a) where
-    pretty = ppControl
-    -- pretty (Control paragraphs) = vcat (map pretty paragraphs)
-instance Pretty a => Pretty (Paragraph' a) where
-    pretty = ppParagraph
-    -- pretty (Paragraph fields) = vcat (map pretty fields ++ [empty])
+-- | This can usually be used as the implementation of protectFieldText
+protectFieldText' :: forall a. (StringLike a, ListLike a Char) => ControlFunctions a => a -> a
+protectFieldText' s =
+    let trimmedLines :: [a]
+        trimmedLines = map (LL.dropWhileEnd isSpace :: a -> a) $ (LL.lines s :: [a])
+        strippedLines :: [a]
+        strippedLines = List.dropWhileEnd LL.null trimmedLines in
+    -- Split the text into lines, drop trailing whitespace from each
+    -- line, and drop trailing blank lines.
+    case strippedLines of
+      [] -> empty
+      (l : ls) ->
+          let -- The first line is indented one space
+              l' = {-LL.cons ' '-} l
+              -- Null lines are replaced by a single '.'  If any line
+              -- is unindented, all will get an additional space of
+              -- indentation.
+              ls' = case all indented ls of
+                      True -> map (\ x -> if LL.null x then (LL.cons ' ' $ singleton '.') else x) ls
+                      False -> map (LL.cons ' ') $ map (\ x -> if LL.null x then (singleton '.') else x) ls in
+          LL.dropWhileEnd isSpace (LL.unlines (l' : ls'))
+    where
+      indented l = maybe True isSpace (LL.find (const True) l)
 
-instance Pretty a => Pretty (Field' a) where
-    pretty = ppField
-    -- pretty (Field (name,value)) = pretty name <> text ":" <> pretty value
-    -- pretty (Comment s) = pretty s
+-- | This may have bad performance issues (dsf: Whoever wrote this
+-- comment should have explained why.)
+instance (ControlFunctions a, Pretty (PP a)) => Pretty (PP (Control' a)) where
+    pPrint = ppControl . unPP
+instance (ControlFunctions a, Pretty (PP a)) => Pretty (PP (Paragraph' a)) where
+    pPrint = ppParagraph . unPP
 
-ppControl :: (Pretty a) => Control' a -> Doc
+instance (ControlFunctions a, Pretty (PP a)) => Pretty (PP (Field' a)) where
+    pPrint = ppField . unPP
+
+ppControl :: (ControlFunctions a, Pretty (PP a)) => Control' a -> Doc
 ppControl (Control paragraph) =
-    cat (intersperse (text "\n") (map ppParagraph paragraph))
+    hcat (intersperse (text "\n") (map ppParagraph paragraph))
 
-ppParagraph :: (Pretty a) => Paragraph' a -> Doc
+ppParagraph :: (ControlFunctions a, Pretty (PP a)) => Paragraph' a -> Doc
 ppParagraph (Paragraph fields) =
-    vcat (map ppField fields)
+    hcat (map (\ x -> ppField x <> text "\n") fields)
 
-ppField :: (Pretty a) => Field' a -> Doc
-ppField (Field (n,v)) = pretty n <> text ":" <> pretty v
-ppField (Comment c) = pretty c
+ppField :: (ControlFunctions a, Pretty (PP a)) => Field' a -> Doc
+ppField (Field (n,v)) = pPrint (PP n) <> text ":" <> pPrint (PP (protectFieldText v))
+ppField (Comment c) = pPrint (PP c)
 
 mergeControls :: [Control' a] -> Control' a
 mergeControls controls =
