@@ -1,4 +1,4 @@
-{-# LANGUAGE DeriveDataTypeable, FlexibleInstances, OverloadedStrings, TypeSynonymInstances #-}
+{-# LANGUAGE DeriveDataTypeable, FlexibleContexts, FlexibleInstances, OverloadedStrings, TypeSynonymInstances #-}
 module Debian.Relation.Common where
 
 -- Standard GHC Modules
@@ -10,9 +10,11 @@ import Data.Function
 import Data.Set as Set (Set, toList)
 import Data.Typeable (Typeable)
 import Debian.Arch (Arch, prettyArch)
-import Debian.Pretty (Pretty(pretty), Doc, text, empty)
+import Debian.Pretty (PP(..))
 import Prelude hiding (map)
 import Text.ParserCombinators.Parsec
+import Text.PrettyPrint (Doc, text, empty)
+import Text.PrettyPrint.HughesPJClass (Pretty(pPrint))
 
 -- Local Modules
 
@@ -29,7 +31,7 @@ data Relation = Rel BinPkgName (Maybe VersionReq) (Maybe ArchitectureReq) derivi
 newtype SrcPkgName = SrcPkgName {unSrcPkgName :: String} deriving (Read, Show, Eq, Ord, Data, Typeable)
 newtype BinPkgName = BinPkgName {unBinPkgName :: String} deriving (Read, Show, Eq, Ord, Data, Typeable)
 
-class Pretty a => PkgName a where
+class Pretty (PP a) => PkgName a where
     pkgNameFromString :: String -> a
 
 instance PkgName BinPkgName where
@@ -53,7 +55,7 @@ prettyOrRelation xs = mconcat . intersperse (text " | ") . List.map prettyRelati
 
 prettyRelation :: Relation -> Doc
 prettyRelation (Rel name ver arch) =
-    pretty name <> maybe empty prettyVersionReq ver <> maybe empty prettyArchitectureReq arch
+    pPrint (PP name) <> maybe empty prettyVersionReq ver <> maybe empty prettyArchitectureReq arch
 
 instance Ord Relation where
     compare (Rel pkgName1 mVerReq1 _mArch1) (Rel pkgName2 mVerReq2 _mArch2) =
@@ -106,23 +108,25 @@ checkVersionReq (Just (EEQ v1)) (Just v2) = v2 == v1
 checkVersionReq (Just (GRE v1)) (Just v2) = v2 >= v1
 checkVersionReq (Just (SGR v1)) (Just v2) = v2 > v1
 
-instance Pretty BinPkgName where
-    pretty = pretty . unBinPkgName
+instance Pretty (PP BinPkgName) where
+    pPrint = text . unBinPkgName . unPP
 
-instance Pretty SrcPkgName where
-    pretty = pretty . unSrcPkgName
+instance Pretty (PP SrcPkgName) where
+    pPrint = text . unSrcPkgName . unPP
 
-instance Pretty Relations where
-    pretty = prettyRelations
+-- | Wrap `PP` around type synonyms that might overlap with the
+-- `Pretty [a]` instance.
+instance Pretty (PP Relations) where
+    pPrint = prettyRelations . unPP
 
-instance Pretty OrRelation where
-    pretty = prettyOrRelation
+instance Pretty (PP OrRelation) where
+    pPrint = prettyOrRelation . unPP
 
-instance Pretty Relation where
-    pretty = prettyRelation
+instance Pretty (PP Relation) where
+    pPrint = prettyRelation . unPP
 
-instance Pretty VersionReq where
-    pretty = prettyVersionReq
+instance Pretty (PP VersionReq) where
+    pPrint = prettyVersionReq . unPP
 
-instance Pretty ArchitectureReq where
-    pretty = prettyArchitectureReq
\ No newline at end of file
+instance Pretty (PP ArchitectureReq) where
+    pPrint = prettyArchitectureReq . unPP
