@@ -1,13 +1,14 @@
-{-# LANGUAGE OverloadedStrings #-}
+{-# LANGUAGE FlexibleInstances, OverloadedStrings #-}
 {-# OPTIONS_GHC -fno-warn-name-shadowing #-}
 module Debian.Sources where
 
 import Data.List (intercalate)
 import Data.Monoid ((<>))
-import Data.Text (pack)
-import Debian.Pretty (Pretty(pretty), text)
+import Debian.Pretty (PP(..))
 import Debian.Release
 import Network.URI (URI, uriToString, parseURI, unEscapeString, escapeURIString, isAllowedInURI)
+import Text.PrettyPrint (text, hcat)
+import Text.PrettyPrint.HughesPJClass (Pretty(pPrint))
 
 data SourceType
     = Deb | DebSrc
@@ -20,18 +21,21 @@ data DebSource
     , sourceDist :: Either String (ReleaseName, [Section])
     } deriving (Eq, Ord)
 
-instance Pretty SourceType where
-    pretty Deb = text "deb"
-    pretty DebSrc = text "deb-src"
+instance Pretty (PP SourceType) where
+    pPrint (PP Deb) = text "deb"
+    pPrint (PP DebSrc) = text "deb-src"
 
-instance Pretty DebSource where
-    pretty (DebSource thetype theuri thedist) =
-        pretty thetype <>
-        text (" " <> pack (uriToString id theuri " ") <>
+instance Pretty (PP DebSource) where
+    pPrint (PP (DebSource thetype theuri thedist)) =
+        pPrint (PP thetype) <>
+        text (" " <> uriToString id theuri " " <>
               case thedist of
                 Left exactPath -> escape exactPath
-                Right (dist, sections) -> pack (releaseName' dist <> " " <> intercalate " " (map sectionName' sections)))
-            where escape = pack . escapeURIString isAllowedInURI
+                Right (dist, sections) -> releaseName' dist <> " " <> intercalate " " (map sectionName' sections))
+            where escape = escapeURIString isAllowedInURI
+
+instance Pretty (PP [DebSource]) where
+    pPrint = hcat . map (\ x -> pPrint (PP x) <> text "\n") . unPP
 
 -- |This is a name given to a combination of parts of one or more
 -- releases that can be specified by a sources.list file.
