@@ -1,8 +1,9 @@
 -- |A module for parsing, comparing, and (eventually) modifying debian version
 -- numbers. <http://www.debian.org/doc/debian-policy/ch-controlfields.html#s-f-Version>
+{-# LANGUAGE FlexibleInstances #-}
 {-# OPTIONS -fno-warn-orphans -fno-warn-unused-do-bind #-}
 module Debian.Version.Common
-    (DebianVersion -- |Exported abstract because the internal representation is likely to change 
+    ( DebianVersion -- |Exported abstract because the internal representation is likely to change 
     , prettyDebianVersion
     , ParseDebianVersion(..)
     , evr		-- DebianVersion -> (Maybe Int, String, Maybe String)
@@ -11,16 +12,21 @@ module Debian.Version.Common
     , revision
     , buildDebianVersion
     , parseDV
-    ) where 
+    ) where
 
 import Data.Char (ord, isDigit, isAlpha)
-import Debian.Pretty (Doc, pretty, render)
+import Debian.Pretty (PP(..))
 import Debian.Version.Internal
 import Text.ParserCombinators.Parsec
 import Text.Regex
+import Text.PrettyPrint (Doc, render)
+import Text.PrettyPrint.HughesPJClass (Pretty(pPrint), text)
 
 prettyDebianVersion :: DebianVersion -> Doc
-prettyDebianVersion (DebianVersion s _) = pretty s
+prettyDebianVersion (DebianVersion s _) = text s
+
+instance Pretty (PP DebianVersion) where
+    pPrint = prettyDebianVersion . unPP
 
 instance Eq DebianVersion where
     (DebianVersion _ v1) == (DebianVersion _ v2) = v1 == v2
